@@ -3,44 +3,7 @@ kcv.rda <-
            regularization = "S", genelist = FALSE, trace = FALSE, 
            parallel = FALSE) 
 {
-    if (!is.factor(y)) {y <- factor(y)}
-    if (length(unique(y)) == 1L) {
-      stop("Input 'y' must contain some variation (i.e., cannot contain \n
-           only a single type of label).")
-    }
-    if (is.null(nfolds)) {
-      nfolds <- 10
-    } else {
-      if (!(is.integer(nfolds) || is.numeric(nfolds))) {
-        stop("Input 'nfolds' must be of class 'integer' or 'numeric'.")
-      }
-      if (length(unique(nfolds)) != 1L) {
-        stop("Input 'nfolds' must contain only a single value.")
-      }
-      if ((nfolds %% 1) != 0) {stop("Input 'nfolds' must be an integer.")}
-      if ((nfolds < 2) | (nfolds > length(y))) {
-        stop("Input 'nfolds' must be an integer between 2 and the \n
-             number of observations, inclusive. Alternatively, the \n
-             number of observations cannot be less than 'nfolds'.")
-      }
-    }
-    if (is.null(parallel)) {
-      parallel <- FALSE
-    } else {
-      if (!(is.logical(parallel))) {
-        stop("Input 'parallel' must be of class 'logical'.")
-      }
-      if (length(unique(parallel)) != 1L) {
-        stop("Input 'parallel' must contain only a single value.")
-      }  
-    }
-    if (is.null(foldid)) {
-      foldid <- sample(rep(1:nfolds, length.out = length(y)))
-    }
-    if (length(unique(foldid)) != as.integer(nfolds)) {
-      stop("Input 'foldid' must contain the number of unique values equal to \n
-           input 'nfolds'.")
-    }
+    kcvcheck(y = y, nfolds = nfolds, parallel = parallel, foldid = foldid)
     if (is.null(prior)) {prior <- table(y) / length(y)}
     grid.row <- nrow(rda.grid)
     cv.rda <- matrix(rep(0, grid.row * nfolds), ncol = nfolds)
@@ -58,8 +21,7 @@ kcv.rda <-
                                           alpha = rda.grid[yy, 1],
                                           delta = rda.grid[yy, 2],
                                           regularization = regularization,
-                                          genelist = genelist, 
-                                          trace = trace)
+                                          genelist = genelist, trace = trace)
                            rda.pred <- predict(rda.fit, x = t(x.train), 
                                                y = y.train, xnew = t(x.test), 
                                                alpha = rda.grid[yy, 1], 
@@ -80,8 +42,8 @@ kcv.rda <-
             rda.fit <- rda(x = t(unlist(x.train)), y = unlist(y.train), 
                            prior = prior, alpha = rda.grid[yy, 1], 
                            delta = rda.grid[yy, 2], 
-                           regularization = regularization, 
-                           genelist = genelist, trace = trace)
+                           regularization = regularization, genelist = genelist, 
+                           trace = trace)
             rda.pred <- predict(rda.fit, x = t(x.train), y = y.train, 
                                 xnew = t(x.test), alpha = rda.grid[yy, 1], 
                                 delta = rda.grid[yy, 2], type = "class") - 1
